phive_generator library
Public API for phive_generator.
External packages and test code import from here. Internal src/ modules
should be imported directly by their path within the package.
Classes
- PhiveAutoTypeGenerator
-
Generates
PTypeAdapterimplementations for@PHiveAutoTypemodels. - PhiveGenerator
-
Generates
PTypeAdapterimplementations for@PHiveTypemodels. - TypeIdRegistry
- Immutable mapping of Dart class names to their assigned Hive type identifiers.